package Swatindex;
use vars qw($AUTOLOAD);
use strict;

# Swat 2.1 
# Last updated on 12/10/97
# Copyright (c) by Chris Kight 1997
#
# A light proxy object that sits in front of all database access objects
# Simply passes on calls to the appropriate db object
#
# Usage:
# indexfile => file of index
# indextype => type of database to use. Legal list defined in config file
#              under :Indexer: db => [list,of,databases]
#              Corresponding database type.pm must exist in ext/db/
# append    => 1 to append, 0 not to
#
# Several    methods are pre-defined including:
# openr()    opens index file for reading
# openw()    opens index file for writing
# closew()   closes index file opened for writing
# closer()   closes index file opened for reading 
# acc_db()   Takes type of db as argument, returns 1 if legal Database type

sub new {
   my $proto = shift;
   my $class = ref($proto) || $proto;
   my $self = { 
        g         => shift,
        append 	  => shift,
	contents  => { contents => ''},
   };
   bless ($self, $class);
   $self->_make_obj();
   return $self;
}

my $obj;

sub _make_obj() {
   my $self = shift;
   my $class = $self->{g}{indextype};     # Create the class ext::db::class
   my $toreq = $self->{g}{indextype}.".pm"; # Require ext/db/class.pm
   require $toreq;
   $obj = $class->new($self->{g}{indexfile},$self->{append});# Create the new obj $obj of ext/db/class.pm
}

sub acc_db() {
   my $self = shift;
   my $value = shift;
   foreach (@$self->{acc_db}) {
      return 1 if ($_ eq $value);
   }
   return 0;
}

sub openr() {
   my $self = shift;
   $obj->openr();
}

sub openw() {
   my $self = shift;
   $obj->openw($self->{g}{indexfile},$self->{g}{append});
}   

sub closew() {
   my $self = shift;
   $obj->closew($self->{g}{indexfile});
}

sub write() {
    my $self = shift;
    my $entry = $_[0];
    if ($obj->exists($entry) && $self->{append}) {
	print "\tSkipping... Already Indexed\n";
    } else {
	$obj->write(@_);
    }
}

sub AUTOLOAD {
    my $self = shift;
    return if $AUTOLOAD =~ /::DESTROY$/;
    my $call = $AUTOLOAD;
    $call =~ s/^.*:://;
    $obj->$call(@_);
}
1;


